@@ -4,6 +4,7 @@ import base64
 import aiohttp
 import asyncio
 import traceback
+import mimetypes
 from cannerflow.csv_wrapper import CsvWrapper
 from cannerflow.json_wrapper import JsonWrapper
 from cannerflow.image_wrapper import ImageWrapper
@@ -171,7 +172,9 @@ class File(object):
                 loop = asyncio.get_event_loop()
                 http_response = loop.run_until_complete(self._put_azure(url=url, data=data, headers=headers))
             else:
+                content_type = mimetypes.guess_type(absolute_path)[0]
                 headers['x-amz-meta-file_info_id'] = info_id
+                headers['Content-Type'] = content_type
                 http_response = self._put(url=url, data=data, headers=headers)
             http_response.raise_for_status()
         except Exception as err:
